/**
 * @file serial.h
 * The serial line handler
 * @author Marko Mkel <marko.makela at iki.fi>
 */

/* Copyright  2001,2002,2004,2006 Marko Mkel.

   This file is part of C2N, a program for processing data tapes in
   Commodore C2N format and other formats.

   C2N is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   C2N is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   The GNU General Public License is often shipped with GNU software, and
   is generally kept in a file called COPYING or LICENSE.  If you do not
   have a copy of the license, write to the Free Software Foundation,
   59 Temple Place, Suite 330, Boston, MA 02111 USA. */

#undef HAS_SERIAL
#ifdef USE_SERIAL
# if defined __WIN32 || defined __WIN32__
#  define HAS_SERIAL
#  include "serialw.h"
# elif defined __AMIGA__
#  define HAS_SERIAL
#  include "seriala.h"
# elif defined __unix || defined __unix__ || defined __APPLE__
#  define HAS_SERIAL
#  include "serialp.h"
# endif /* POSIX termios */
#endif /* USE_SERIAL */

#ifdef HAS_SERIAL
/** Set up the serial communication subsystem
 * @param dev		serial device driver name
 * @param fast		nonzero=fast mode (unsafe with USB RS-232 adapters)
 * @return		zero on success, nonzero on failure
 */
int
serial_init (const char* dev, int fast);

/** Clean up the serial communication subsystem */
void
serial_cleanup (void);

/** Read a pulse from the serial line
 * @return	the read pulse
 */
enum pulse
sp_read (void);

/** Empty the serial buffers */
void
serial_empty (void);

/** Flush the serial output buffer */
void
serial_flush (void);

/** Send a command to the C2N232 device
 * @param buf	the command block
 * @param len	the length of the block
 * @return	zero on success, nonzero on failure
 */
int
serial_command (unsigned char* buf,
		unsigned len);

/** Disable the serial read timeout
 * @return	zero on success, nonzero on failure
 */
int
serial_timeout (void);

/** Make the C2N232 go idle */
void
serial_go_idle (void);

/** Write a pulse to the serial line or to standard output
 * @param p	the pulse to be written
 */
void
p_write (enum pulse p);
#endif /* HAS_SERIAL */
